@@ -1,5 +1,5 @@
 ##
-#     Project: GNOME App Folders Manager
+#     Project: GNOME AppFolders Manager
 # Description: Manage GNOME Shell applications folders
 #      Author: Fabio Castelli (Muflone) <muflone@muflone.com>
 #   Copyright: 2016-2022 Fabio Castelli
@@ -18,13 +18,16 @@
 #  along with this program.  If not, see <https://www.gnu.org/licenses/>.
 ##
 
+import logging
+
 from gi.repository import Gtk
 
 
-class UIMessageDialog(Gtk.Window):
+class UIMessageDialog(object):
     def __init__(self, parent, message_type, title, msg1, msg2,
                  buttons, default_response_id):
         """Prepare the message dialog"""
+        logging.debug(f'{self.__class__.__name__} init')
         self.dialog = Gtk.MessageDialog(parent=parent,
                                         flags=Gtk.DialogFlags.MODAL,
                                         message_type=message_type,
@@ -37,12 +40,14 @@ class UIMessageDialog(Gtk.Window):
 
     def show(self):
         """Show the dialog"""
+        logging.debug(f'{self.__class__.__name__} show')
         result = self.dialog.run()
         self.dialog.hide()
         return result
 
     def destroy(self):
         """Destroy the dialog"""
+        logging.debug(f'{self.__class__.__name__} destroy')
         self.dialog.destroy()
         self.dialog = None
 
